[GRASS-SVN] r66332 - in grass/trunk: gui/wxpython/vnet lib/python/pygrass/raster lib/python/temporal locale/po scripts/v.what.strds vector/v.net
svn_grass at osgeo.org
svn_grass at osgeo.org
Fri Sep 25 06:48:44 PDT 2015
Author: neteler
Date: 2015-09-25 06:48:44 -0700 (Fri, 25 Sep 2015)
New Revision: 66332
Modified:
grass/trunk/gui/wxpython/vnet/dialogs.py
grass/trunk/lib/python/pygrass/raster/__init__.py
grass/trunk/lib/python/temporal/abstract_space_time_dataset.py
grass/trunk/lib/python/temporal/core.py
grass/trunk/lib/python/temporal/space_time_datasets.py
grass/trunk/locale/po/grasslibs_ar.po
grass/trunk/locale/po/grasslibs_cs.po
grass/trunk/locale/po/grasslibs_de.po
grass/trunk/locale/po/grasslibs_el.po
grass/trunk/locale/po/grasslibs_es.po
grass/trunk/locale/po/grasslibs_fi.po
grass/trunk/locale/po/grasslibs_fr.po
grass/trunk/locale/po/grasslibs_it.po
grass/trunk/locale/po/grasslibs_ja.po
grass/trunk/locale/po/grasslibs_ko.po
grass/trunk/locale/po/grasslibs_lv.po
grass/trunk/locale/po/grasslibs_ml.po
grass/trunk/locale/po/grasslibs_pl.po
grass/trunk/locale/po/grasslibs_pt.po
grass/trunk/locale/po/grasslibs_pt_br.po
grass/trunk/locale/po/grasslibs_ro.po
grass/trunk/locale/po/grasslibs_ru.po
grass/trunk/locale/po/grasslibs_sl.po
grass/trunk/locale/po/grasslibs_th.po
grass/trunk/locale/po/grasslibs_tr.po
grass/trunk/locale/po/grasslibs_vi.po
grass/trunk/locale/po/grasslibs_zh.po
grass/trunk/locale/po/grassmods_ar.po
grass/trunk/locale/po/grassmods_cs.po
grass/trunk/locale/po/grassmods_de.po
grass/trunk/locale/po/grassmods_el.po
grass/trunk/locale/po/grassmods_es.po
grass/trunk/locale/po/grassmods_fi.po
grass/trunk/locale/po/grassmods_fr.po
grass/trunk/locale/po/grassmods_it.po
grass/trunk/locale/po/grassmods_ja.po
grass/trunk/locale/po/grassmods_ko.po
grass/trunk/locale/po/grassmods_lv.po
grass/trunk/locale/po/grassmods_pl.po
grass/trunk/locale/po/grassmods_pt.po
grass/trunk/locale/po/grassmods_pt_br.po
grass/trunk/locale/po/grassmods_ro.po
grass/trunk/locale/po/grassmods_ru.po
grass/trunk/locale/po/grassmods_sl.po
grass/trunk/locale/po/grassmods_th.po
grass/trunk/locale/po/grassmods_tr.po
grass/trunk/locale/po/grassmods_vi.po
grass/trunk/locale/po/grassmods_zh.po
grass/trunk/locale/po/grasswxpy_cs.po
grass/trunk/locale/po/grasswxpy_de.po
grass/trunk/locale/po/grasswxpy_el.po
grass/trunk/locale/po/grasswxpy_es.po
grass/trunk/locale/po/grasswxpy_fi.po
grass/trunk/locale/po/grasswxpy_fr.po
grass/trunk/locale/po/grasswxpy_id.po
grass/trunk/locale/po/grasswxpy_it.po
grass/trunk/locale/po/grasswxpy_ja.po
grass/trunk/locale/po/grasswxpy_ko.po
grass/trunk/locale/po/grasswxpy_lv.po
grass/trunk/locale/po/grasswxpy_ml.po
grass/trunk/locale/po/grasswxpy_pl.po
grass/trunk/locale/po/grasswxpy_pt.po
grass/trunk/locale/po/grasswxpy_pt_br.po
grass/trunk/locale/po/grasswxpy_ro.po
grass/trunk/locale/po/grasswxpy_ru.po
grass/trunk/locale/po/grasswxpy_th.po
grass/trunk/locale/po/grasswxpy_tr.po
grass/trunk/locale/po/grasswxpy_vi.po
grass/trunk/locale/po/grasswxpy_zh.po
grass/trunk/scripts/v.what.strds/v.what.strds.py
grass/trunk/vector/v.net/turntable.c
Log:
fix msg grammar
Modified: grass/trunk/gui/wxpython/vnet/dialogs.py
===================================================================
--- grass/trunk/gui/wxpython/vnet/dialogs.py 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/gui/wxpython/vnet/dialogs.py 2015-09-25 13:48:44 UTC (rev 66332)
@@ -795,7 +795,7 @@
if "input" in err_params:
GMessage(parent = self,
- message = _("Input vector map does not exists."))
+ message = _("Input vector map does not exist."))
if ["turn_layer", "turn_cat_layer"] in err_params:
GMessage(parent = self, message = "Please choose existing turntable layer and unique categories layer in Parameters tab.")
Modified: grass/trunk/lib/python/pygrass/raster/__init__.py
===================================================================
--- grass/trunk/lib/python/pygrass/raster/__init__.py 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/lib/python/pygrass/raster/__init__.py 2015-09-25 13:48:44 UTC (rev 66332)
@@ -558,7 +558,7 @@
self._fd = libraster.Rast_open_new(self.name, self._gtype)
else:
if self.mode == "r":
- str_err = _("Raster map <{0}> does not exists")
+ str_err = _("Raster map <{0}> does not exist")
raise OpenError(str_err.format(self.name))
self._gtype = RTYPE[self.mtype]['grass type']
Modified: grass/trunk/lib/python/temporal/abstract_space_time_dataset.py
===================================================================
--- grass/trunk/lib/python/temporal/abstract_space_time_dataset.py 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/lib/python/temporal/abstract_space_time_dataset.py 2015-09-25 13:48:44 UTC (rev 66332)
@@ -327,7 +327,7 @@
dbif, connected = init_dbif(dbif)
- # We need to create the register table if it does not exists
+ # We need to create the register table if it does not exist
stds_register_table = self.get_map_register()
# Create the map register table
Modified: grass/trunk/lib/python/temporal/core.py
===================================================================
--- grass/trunk/lib/python/temporal/space_time_datasets.py 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/lib/python/temporal/space_time_datasets.py 2015-09-25 13:48:44 UTC (rev 66332)
@@ -171,7 +171,7 @@
the map will be exported using r.out.bin to a temporary location
and assigned to the memmap object that is returned by this function.
- In case the raster map does not exists, an empty temporary
+ In case the raster map does not exist, an empty temporary
binary file will be created and assigned to the memap object.
You need to call the write function to write the memmap
@@ -505,7 +505,7 @@
the map will be exported using r3.out.bin to a temporary location
and assigned to the memmap object that is returned by this function.
- In case the 3D raster map does not exists, an empty temporary
+ In case the 3D raster map does not exist, an empty temporary
binary file will be created and assigned to the memap object.
You need to call the write function to write the memmap
Modified: grass/trunk/locale/po/grasslibs_ar.po
===================================================================
--- grass/trunk/locale/po/grasslibs_ar.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_ar.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3640,7 +3640,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "'%s' لم يمكن ÙØªØ Ù…Ù„Ù Ø§Ù„ØªØ§Ø±ÙŠØ® للÙيكتور"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_cs.po
===================================================================
--- grass/trunk/locale/po/grasslibs_cs.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_cs.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3692,7 +3692,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "Tabulka <%s> připojená k vektorové mapě <%s> neexistuje"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_de.po
===================================================================
--- grass/trunk/locale/po/grasslibs_de.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_de.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3686,7 +3686,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "Tabelle <%s> verknüpft mit Vektorkarte <%s> existiert nicht."
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_el.po
===================================================================
--- grass/trunk/locale/po/grasslibs_el.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_el.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3680,7 +3680,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr ""
"Ο πίνακας <%s> που είναι συνδεδεμÎνος με τον διανυσματικό χάÏτη <%s> δεν "
"υπάÏχει"
Modified: grass/trunk/locale/po/grasslibs_es.po
===================================================================
--- grass/trunk/locale/po/grasslibs_es.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_es.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3826,7 +3826,7 @@
#
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "La tabla <%s> enlazada con el mapa vectorial <%s> no existe."
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_fi.po
===================================================================
--- grass/trunk/locale/po/grasslibs_fi.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_fi.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3503,7 +3503,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr ""
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_fr.po
===================================================================
--- grass/trunk/locale/po/grasslibs_fr.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_fr.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3718,7 +3718,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "La table <%s> liée à la carte vecteur <%s> n'existe pas "
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_it.po
===================================================================
--- grass/trunk/locale/po/grasslibs_it.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_it.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3696,7 +3696,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "Tabella <%s> collegata al vettoriale <%s> non esiste"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_ja.po
===================================================================
--- grass/trunk/locale/po/grasslibs_ja.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_ja.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3685,7 +3685,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "ベクトルマップ <%s> ã«ãƒªãƒ³ã‚¯ã™ã‚‹ãƒ†ãƒ¼ãƒ–ル <%s> ã¯å˜åœ¨ã—ã¾ã›ã‚“"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_ko.po
===================================================================
--- grass/trunk/locale/po/grasslibs_ko.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_ko.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3599,7 +3599,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "임시파ì¼ì„ ì—´ 수 없습니다"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_lv.po
===================================================================
--- grass/trunk/locale/po/grasslibs_lv.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_lv.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3628,7 +3628,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "Nevar atvērt vēsturi vektoram '%s'"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_ml.po
===================================================================
--- grass/trunk/locale/po/grasslibs_ml.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_ml.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3566,7 +3566,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "à´—àµà´°àµ‚à´ªàµà´ªàµ <%s> കാലിയാണàµâ€Œ \n"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_pl.po
===================================================================
--- grass/trunk/locale/po/grasslibs_pl.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_pl.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3657,7 +3657,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "Tabela <%s> podłączona do mapy wektorowej <%s> nie istnieje"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_pt.po
===================================================================
--- grass/trunk/locale/po/grasslibs_pt.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_pt.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3678,7 +3678,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "Impossível abrir topologia para mapa vetorial <%s>"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_pt_br.po
===================================================================
--- grass/trunk/locale/po/grasslibs_pt_br.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_pt_br.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3663,7 +3663,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "Não consegui abrir histórico para o vetor %s"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_ro.po
===================================================================
--- grass/trunk/locale/po/grasslibs_ro.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_ro.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3569,7 +3569,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "Harta raster <%s> nu este găsită"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_ru.po
===================================================================
--- grass/trunk/locale/po/grasslibs_ru.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_ru.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3694,7 +3694,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "Таблица <%s> ÑвÑÐ·Ð°Ð½Ð½Ð°Ñ Ñ Ð²ÐµÐºÑ‚Ð¾Ñ€Ð½Ñ‹Ð¼ Ñлоем <%s> не ÑущеÑтвует"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_sl.po
===================================================================
--- grass/trunk/locale/po/grasslibs_sl.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_sl.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3663,7 +3663,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "Ne morem odpreti datoteke z zgodovino za vektor '%s'"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_th.po
===================================================================
--- grass/trunk/locale/po/grasslibs_th.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_th.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3682,7 +3682,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "ไม่สามารถค้นหาตาราง <%s> ที่เชื่à¸à¸¡à¸à¸±à¸šà¸‚้à¸à¸¡à¸¹à¸¥à¹€à¸Šà¸´à¸‡à¹€à¸ªà¹‰à¸™ <%s>"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_tr.po
===================================================================
--- grass/trunk/locale/po/grasslibs_tr.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_tr.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3611,7 +3611,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "<%s> raster haritası boş"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_vi.po
===================================================================
--- grass/trunk/locale/po/grasslibs_vi.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_vi.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3684,7 +3684,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "Bảng <%s> được liên kết và o bản đồ vec-tơ <%s> không tồn tại"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grasslibs_zh.po
===================================================================
--- grass/trunk/locale/po/grasslibs_zh.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasslibs_zh.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -3680,7 +3680,7 @@
#: ../lib/python/pygrass/raster/__init__.py:432
#, fuzzy, python-brace-format
-msgid "Raster map <{0}> does not exists"
+msgid "Raster map <{0}> does not exist"
msgstr "æ— æ³•æ‰“å¼€çŸ¢é‡'%s'的历å²è®°å½•"
#: ../lib/python/pygrass/raster/abstract.py:274
Modified: grass/trunk/locale/po/grassmods_ar.po
===================================================================
--- grass/trunk/locale/po/grassmods_ar.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_ar.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10644,7 +10644,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "الخريطة الراسترية المطلوب الضبط عليها"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_cs.po
===================================================================
--- grass/trunk/locale/po/grassmods_cs.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_cs.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10620,7 +10620,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "Tabulka <%s> v databázi <%s> neexistuje"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_de.po
===================================================================
--- grass/trunk/locale/po/grassmods_de.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_de.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10557,7 +10557,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "Die Tabelle <%s> existiert nicht in der Datenbank <%s>."
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_el.po
===================================================================
--- grass/trunk/locale/po/grassmods_el.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_el.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10208,7 +10208,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "Ο χάÏτης raster <%s> δεν βÏÎθηκε"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_es.po
===================================================================
--- grass/trunk/locale/po/grassmods_es.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_es.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10632,7 +10632,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "La tabla <%s> no existe en la base de datos <%s>"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_fi.po
===================================================================
--- grass/trunk/locale/po/grassmods_fi.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_fi.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -9805,7 +9805,7 @@
#: ../vector/v.net/turntable.c:670
#, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr ""
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_fr.po
===================================================================
--- grass/trunk/locale/po/grassmods_fr.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_fr.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -11082,7 +11082,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "La table <%s> n'existe pas dans la base de données <%s>"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_it.po
===================================================================
--- grass/trunk/locale/po/grassmods_it.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_it.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10488,7 +10488,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "La tabella <%s> non esiste nel database <%s>"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_ja.po
===================================================================
--- grass/trunk/locale/po/grassmods_ja.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_ja.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10503,7 +10503,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "テーブル <%s> ã¯ãƒ‡ãƒ¼ã‚¿ãƒ™ãƒ¼ã‚¹ <%s> ä¸ã«ã‚ã‚Šã¾ã›ã‚“"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_ko.po
===================================================================
--- grass/trunk/locale/po/grassmods_ko.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_ko.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10266,7 +10266,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "ì¶œë ¥í• ê²©ìžì§€ë„"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_lv.po
===================================================================
--- grass/trunk/locale/po/grassmods_lv.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_lv.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10625,7 +10625,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "PÄrkodÄ“t rastra kartes."
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_pl.po
===================================================================
--- grass/trunk/locale/po/grassmods_pl.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_pl.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10530,7 +10530,7 @@
# kolejność %s ma chyba znaczenie -> zmiana wypacza sens
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "Tabela <%s> nie istnieje w bazie danych <%s>"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_pt.po
===================================================================
--- grass/trunk/locale/po/grassmods_pt.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_pt.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10761,7 +10761,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "Tabela <%s> não existe no banco de dados <%s>"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_pt_br.po
===================================================================
--- grass/trunk/locale/po/grassmods_pt_br.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_pt_br.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10757,7 +10757,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "Tabela <%s> não existe no banco de dados <%s>"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_ro.po
===================================================================
--- grass/trunk/locale/po/grassmods_ro.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_ro.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -9902,7 +9902,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "<%s> deja există în mapset <%s>"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_ru.po
===================================================================
--- grass/trunk/locale/po/grassmods_ru.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_ru.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10624,7 +10624,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "Таблица <%s> не ÑущеÑтвует в базе данных <%s>"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_sl.po
===================================================================
--- grass/trunk/locale/po/grassmods_sl.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_sl.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10674,7 +10674,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "Rastrski sloj kateremu naj se regija prilagodi"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_th.po
===================================================================
--- grass/trunk/locale/po/grassmods_th.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_th.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10609,7 +10609,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "ตาราง <%s> ไม่มีà¸à¸¢à¸¹à¹ˆà¹ƒà¸™à¸à¸²à¸™à¸‚้à¸à¸¡à¸¹à¸¥ <%s>"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_tr.po
===================================================================
--- grass/trunk/locale/po/grassmods_tr.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_tr.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10471,7 +10471,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "<%s> tablosu <%s> veritabanında yok"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_vi.po
===================================================================
--- grass/trunk/locale/po/grassmods_vi.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_vi.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10615,7 +10615,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "Bảng <%s> không có trong CSDL <%s>"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grassmods_zh.po
===================================================================
--- grass/trunk/locale/po/grassmods_zh.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grassmods_zh.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -10618,7 +10618,7 @@
#: ../vector/v.net/turntable.c:670
#, fuzzy, c-format
-msgid "Arc layer <%s> does not exists in map <%s>."
+msgid "Arc layer <%s> does not exist in map <%s>."
msgstr "包å«ç»“æžœçš„æ …æ ¼å›¾çš„å称"
#: ../vector/v.net/turntable.c:675
Modified: grass/trunk/locale/po/grasswxpy_cs.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_cs.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_cs.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6870,7 +6870,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "Vektorová mapa <%s> nebyla nalezena."
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_de.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_de.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_de.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6755,7 +6755,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "Verzeichnis %s existiert nicht."
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_el.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_el.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_el.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6463,7 +6463,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "Ο φάκελος %s δεν υπάÏχει,"
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_es.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_es.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_es.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6835,7 +6835,7 @@
msgstr "Cargando datos."
#: ../gui/wxpython/vnet/dialogs.py:798
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "Mapa vectorial de entrada no existe."
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_fi.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_fi.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_fi.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6285,7 +6285,7 @@
msgstr ""
#: ../gui/wxpython/vnet/dialogs.py:798
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr ""
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_fr.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_fr.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_fr.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6698,7 +6698,7 @@
msgstr ""
#: ../gui/wxpython/vnet/dialogs.py:798
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "La couche vecteur entrée n'existe pas."
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_id.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_id.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_id.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6971,7 +6971,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "ERROR: Mapset <%s> tidak ada"
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_it.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_it.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_it.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6567,7 +6567,7 @@
msgstr "Creando la tabella delle svolte..."
#: ../gui/wxpython/vnet/dialogs.py:798
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "Il vettoriale di input non esiste."
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_ja.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_ja.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_ja.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6778,7 +6778,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "ベクトルマップ <%s> ãŒè¦‹ã¤ã‹ã‚Šã¾ã›ã‚“"
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_ko.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_ko.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_ko.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6268,7 +6268,7 @@
msgstr ""
#: ../gui/wxpython/vnet/dialogs.py:798
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr ""
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_lv.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_lv.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_lv.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6432,7 +6432,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "Īpašība %s neeksistē"
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_ml.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_ml.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_ml.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6709,7 +6709,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "മാപàµà´ªàµ <%s> à´•à´£àµà´®à´¨à´¿à´²àµà´²"
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_pl.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_pl.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_pl.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6650,7 +6650,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "Katalog %s nie istnieje."
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_pt.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_pt.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_pt.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -7008,7 +7008,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "Mapa <%s> não encontrado"
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_pt_br.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_pt_br.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_pt_br.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -7149,7 +7149,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "Mapa <%s> não encontrado"
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_ro.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_ro.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_ro.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6796,7 +6796,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "Directorul %s nu există."
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_ru.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_ru.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_ru.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6931,7 +6931,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "Слой <%s> не найден."
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_th.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_th.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_th.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6683,7 +6683,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "à¹à¸œà¸™à¸—ี่เชิงภาพไม่ใช่ 3มิติ"
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_tr.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_tr.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_tr.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6946,7 +6946,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "<%s>haritası bulunamadı."
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_vi.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_vi.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_vi.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6945,7 +6945,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "Không tìm thấy bản đồ <%s>."
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/locale/po/grasswxpy_zh.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_zh.po 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/locale/po/grasswxpy_zh.po 2015-09-25 13:48:44 UTC (rev 66332)
@@ -6837,7 +6837,7 @@
#: ../gui/wxpython/vnet/dialogs.py:798
#, fuzzy
-msgid "Input vector map does not exists."
+msgid "Input vector map does not exist."
msgstr "æ …æ ¼åœ°å›¾ [%s] 未å‘现"
#: ../gui/wxpython/vnet/dialogs.py:816
Modified: grass/trunk/scripts/v.what.strds/v.what.strds.py
===================================================================
--- grass/trunk/scripts/v.what.strds/v.what.strds.py 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/scripts/v.what.strds/v.what.strds.py 2015-09-25 13:48:44 UTC (rev 66332)
@@ -22,6 +22,7 @@
#% keyword: position
#% keyword: querying
#% keyword: attribute table
+#% keyword: time
#%end
#%option G_OPT_V_INPUT
Modified: grass/trunk/vector/v.net/turntable.c
===================================================================
--- grass/trunk/vector/v.net/turntable.c 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/vector/v.net/turntable.c 2015-09-25 13:48:44 UTC (rev 66332)
@@ -667,17 +667,17 @@
tucfield = Vect_get_field_number(&InMap, opt->tucfield->answer);
if (!Vect_get_field(&InMap, afield))
- G_fatal_error(_("Arc layer <%s> does not exists in map <%s>."),
+ G_fatal_error(_("Arc layer <%s> does not exist in map <%s>."),
opt->afield_opt->answer, opt->output->answer);
if (Vect_get_field(&InMap, tfield))
G_warning(_
- ("Layer <%s> already exists in map <%s>.\nIt will be overwritten by tlayer data."),
+ ("Layer <%s> already exist in map <%s>.\nIt will be overwritten by tlayer data."),
opt->tfield->answer, opt->output->answer);
if (Vect_get_field(&InMap, tucfield))
G_warning(_
- ("Layer <%s> already exists in map <%s>.\nIt will be overwritten by tuclayer data."),
+ ("Layer <%s> already exist in map <%s>.\nIt will be overwritten by tuclayer data."),
opt->tucfield->answer, opt->output->answer);
ttb_name = NULL;
More information about the grass-commit
mailing list
--- grass/trunk/lib/python/temporal/core.py 2015-09-25 13:19:52 UTC (rev 66331)
+++ grass/trunk/lib/python/temporal/core.py 2015-09-25 13:48:44 UTC (rev 66332)
@@ -463,7 +463,7 @@
# exists
if driver == "sqlite" and not os.path.exists(database):
message_interface.warning("Temporal database connection defined as:\n" + \
- database + "\nBut database file does not exists.")
+ database + "\nBut database file does not exist.")
return tgis_mapsets
@@ -474,7 +474,7 @@
"""This function set the correct database backend from GRASS environmental
variables and creates the grass temporal database structure for raster,
vector and raster3d maps as well as for the space-time datasets strds,
- str3ds and stvds in case it does not exists.
+ str3ds and stvds in case it does not exist.
Several global variables are initiated and the messenger and C-library
interface subprocesses are spawned.
@@ -759,7 +759,7 @@
msgr.message(_("Creating temporal database: %s" % (str(tgis_database_string))))
if tgis_backend == "sqlite":
# We need to create the sqlite3 database path if it does not exists
tgis_dir = os.path.dirname(tgis_database_string)
if not os.path.exists(tgis_dir):
try:
@@ -759,7 +759,7 @@
msgr.message(_("Creating temporal database: %s" % (str(tgis_database_string))))
if tgis_backend == "sqlite":
- # We need to create the sqlite3 database path if it does not exists
+ # We need to create the sqlite3 database path if it does not exist
tgis_dir = os.path.dirname(tgis_database_string)
if not os.path.exists(tgis_dir):
Modified: grass/trunk/lib/python/temporal/space_time_datasets.py
===================================================================